# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: informaticsmatters/protobuf/accountserver/merchant_authority_request_response_message.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n[informaticsmatters/protobuf/accountserver/merchant_authority_request_response_message.proto\x12)informaticsmatters.protobuf.accountserver\"\xba\x03\n\'MerchantAuthorityRequestResponseMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x15\n\rmerchant_kind\x18\x02 \x01(\t\x12\x15\n\rmerchant_name\x18\x03 \x01(\t\x12\x13\n\x0bmerchant_id\x18\x04 \x01(\r\x12T\n\toperation\x18\x05 \x01(\x0e\x32\x41.informaticsmatters.protobuf.accountserver.AuthorityOperationEnum\x12\x10\n\x08ref_name\x18\x06 \x01(\t\x12\x0e\n\x06ref_id\x18\x07 \x01(\t\x12R\n\x08response\x18\n \x01(\x0e\x32@.informaticsmatters.protobuf.accountserver.AuthorityResponseEnum\x12\x1a\n\x12\x61uthorisation_code\x18\x0b \x01(\r\x12\x0e\n\x06reason\x18\x0c \x01(\t\x12\x0c\n\x04user\x18\x10 \x01(\t\x12\x0f\n\x07product\x18\x11 \x01(\t\x12\x0c\n\x04unit\x18\x12 \x01(\t\x12\x14\n\x0corganisation\x18\x13 \x01(\t*\x91\x01\n\x16\x41uthorityOperationEnum\x12(\n$AUTHORITY_OPERATION_ENUM_UNSPECIFIED\x10\x00\x12\'\n#AUTHORITY_OPERATION_ENUM_PROCESSING\x10\x01\x12$\n AUTHORITY_OPERATION_ENUM_STORAGE\x10\x02*\x89\x01\n\x15\x41uthorityResponseEnum\x12\'\n#AUTHORITY_RESPONSE_ENUM_UNSPECIFIED\x10\x00\x12#\n\x1f\x41UTHORITY_RESPONSE_ENUM_GRANTED\x10\x01\x12\"\n\x1e\x41UTHORITY_RESPONSE_ENUM_DENIED\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'informaticsmatters.protobuf.accountserver.merchant_authority_request_response_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_AUTHORITYOPERATIONENUM']._serialized_start=584
  _globals['_AUTHORITYOPERATIONENUM']._serialized_end=729
  _globals['_AUTHORITYRESPONSEENUM']._serialized_start=732
  _globals['_AUTHORITYRESPONSEENUM']._serialized_end=869
  _globals['_MERCHANTAUTHORITYREQUESTRESPONSEMESSAGE']._serialized_start=139
  _globals['_MERCHANTAUTHORITYREQUESTRESPONSEMESSAGE']._serialized_end=581
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: informaticsmatters/protobuf/datamanager/pod_message.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9informaticsmatters/protobuf/datamanager/pod_message.proto\x12\'informaticsmatters.protobuf.datamanager\"\xce\x01\n\nPodMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x10\n\x08pod_name\x18\x02 \x01(\t\x12\x0c\n\x04task\x18\x03 \x01(\t\x12\x0f\n\x07purpose\x18\x04 \x01(\r\x12\r\n\x05phase\x18\x05 \x01(\t\x12\x17\n\x0fstart_timestamp\x18\x06 \x01(\t\x12\x18\n\x10\x66inish_timestamp\x18\x07 \x01(\t\x12\x15\n\rhas_exit_code\x18\x10 \x01(\x08\x12\x11\n\texit_code\x18\x11 \x01(\r\x12\x10\n\x08instance\x18\x12 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'informaticsmatters.protobuf.datamanager.pod_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PODMESSAGE']._serialized_start=103
  _globals['_PODMESSAGE']._serialized_end=309
# @@protoc_insertion_point(module_scope)
